.. QuakerDocs documentation master file, created on Mon Jun 14 13:53:37 2021.

QuakerDocs - Documentation
===========================

Welcome to QuakerDocs!

QuakerDocs is a modern and reliable static documentation generator.
It was designed from the ground up to replace older documentation generators.
It generates a fully static web page with your documentation, so it can work without a server.
Some of the features that QuakerDocs has are:

.. |fa-fast-forward| raw:: html

   <i class="fa fa-fast-forward" aria-hidden="true"></i>

.. |fa-file-text| raw:: html

   <i class="fa fa-file-text" aria-hidden="true"></i>

.. |fa-tachometer| raw:: html

   <i class="fa fa-tachometer" aria-hidden="true"></i>

.. |fa-bookmark| raw:: html

   <i class="fa fa-bookmark" aria-hidden="true"></i>

.. |fa-adjust| raw:: html

   <i class="fa fa-adjust" aria-hidden="true"></i>

.. |fa-terminal| raw:: html

   <i class="fa fa-terminal" aria-hidden="true"></i>


- Fast generation of a static website  |fa-fast-forward|
- Write documentation using reStructuredText  |fa-file-text|
- Super-fast live search  |fa-tachometer|
- Handy bookmarking system  |fa-bookmark|
- Easily configurable  |fa-adjust|
- Only takes one command!  |fa-terminal|

.. page:

.. toctree::
   :maxdepth: 2
   :caption: Another page

   page